@@ -268,7 +268,7 @@ class DcsConnection:
             return
 
         if(msgtype == 6):
-            logging.info(str(id(self)) + " TID: " + str(tid) + "; Calc Log Daten (für MSG.Type 2).")
+            logging.info(str(id(self)) + " TID: " + str(tid) + "; Received Calc Log Data (for MSG-Type 2).")
             nack=True
             try:
                 self.loadlogdata()
@@ -284,7 +284,7 @@ class DcsConnection:
             return
 
         if(msgtype == 7):
-            logging.info(str(id(self)) + " TID: " + str(tid) + "; Send Log Daten (MSG.Type 2).")
+            logging.info(str(id(self)) + " TID: " + str(tid) + "; Received Send Log Daten (MSG-Type 2).")
             try:
                 self.sendlogdata(tid=tid)
             except Exception as e:
