@@ -216,40 +216,40 @@ class DeviceDcElwa(ModbusRtuDevice):
         
         value = ModbusRtuDevice.getdataset(self,"temp1")
         if value != None and ( value > 1200 or value < 0 ):
-            logging.error("[Device] " + self.getidentifier() + " - Temp1 sensor error: " + str(value))
+            logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Temp1 sensor error: " + str(value))
             temp1error = True
         else:
             temp1error = False
 
         value = ModbusRtuDevice.getdataset(self,"temp2")
         if value != None and ( value > 1200 or value < 0 ):
-            logging.error("[Device] " + self.getidentifier() + " - Temp2 sensor error: " + str(value))
+            logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Temp2 sensor error: " + str(value))
             temp2error = True
         else:
             temp2error = False
 
         value = ModbusRtuDevice.getdataset(self,"operation_mode")
         if value != None and value > 100 :
-            logging.error("[Device] " + self.getidentifier() + " - Operation Mode " + str(value) + " detected.")
+            logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Operation Mode " + str(value) + " detected.")
             opmodeError = True
         else:
             opmodeError = False
 
         modbusErrorRate = self.getcommunicationerrorsrate()
         if modbusErrorRate != None and modbusErrorRate > MODBUSWARNLEVEL and modbusErrorRate < 1:
-            logging.error("[Device] " + self.getidentifier() + " - Modbus error rate to hight " + str(modbusErrorRate) + ".")
+            logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Modbus error rate to hight " + str(modbusErrorRate) + ".")
             modbusWarning = True
         else:
             modbusWarning = False
         if modbusErrorRate == 1 :
-            logging.error("[Device] " + self.getidentifier() + " - Modbus communication to device not working.")
+            logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Modbus communication to device not working.")
             modbusError = True
         else:
             modbusError = False
 
         value = ModbusRtuDevice.getdataset(self, "tempchip")
         if value == 0 and modbusError == False:
-            logging.error("[Device] " + self.getidentifier() + " - No IR Connection to Device.")
+            logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - No IR Connection to Device.")
             irError = True
             self.__irerror__ = True
         else:
@@ -257,7 +257,7 @@ class DeviceDcElwa(ModbusRtuDevice):
             self.__irerror__ = False
 
         if self.__checkRegiterTimeStamp__() != True and modbusError == False:
-            logging.error("[Device] " + self.getidentifier() + " - Register values too old. Communication errors expected.")
+            logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Register values too old. Communication errors expected.")
             registerError = True
         else:
             registerError = False
@@ -430,14 +430,14 @@ if __name__ == "__main__":
 
     try:
         while True:
-            print(color('[Device] test active. Press CTRL+C to stop', fore='blue', style='bright'))
+            print(color('[DeviceDcElwa] test active. Press CTRL+C to stop', fore='blue', style='bright'))
             device.showinfo()
             device.showcommunicationerrors()
             device.showcommunicationerrorsrate()
             device.__supervise__()
             time.sleep(10)
     except KeyboardInterrupt as e:
-        print("[Device] Stopping Test...")
+        print("[DeviceDcElwa] Stopping Test...")
         device.stop()
 
     input("Press ENTER to start communication tests")
@@ -462,7 +462,7 @@ if __name__ == "__main__":
     device3.start()
     try:
         while True:
-            print(color('[Device] DCS communication active. Press CTRL+C to stop', fore='blue', style='bright'))
+            print(color('[DeviceDcElwa] DCS communication active. Press CTRL+C to stop', fore='blue', style='bright'))
             # device.showInfo()
             device.showcommunicationerrors()
             device.showcommunicationerrorsrate()
