@@ -15,7 +15,7 @@ sys.path.append(os.path.normpath(os.path.join(SCRIPT_DIR, PACKAGE_PARENT)))
 
 from mypvdevices.DcsConnection import DcsConnection
 
-BUILDNR = "1.2101.9"
+BUILDNR = "1.2101.13"
 
 JOINTIMEOUT = 5
 SERIALLEN = 16
@@ -77,16 +77,16 @@ class ModbusDevice:
         if connection != None:
             if(connection.addDevice(self)):
                 self.__connections__.append(connection)
-                logging.debug("[Device] ID " + str(self.__serial__) + " Added connection to device")
+                logging.debug("[ModbusDevice] ID " + str(self.__serial__) + " Added connection to device")
             else:
-                logging.error("[Device] ID " + str(self.__serial__) + " Failed adding connection to device")
+                logging.error("[ModbusDevice] ID " + str(self.__serial__) + " Failed adding connection to device")
                 raise Exception("cannot add connection")
         else:
             raise TypeError("invalid connection")
 
     def start(self):
         self.__running__ = True
-        logging.debug("[Device] ID " + str(self.__serial__) + " starting...")
+        logging.debug("[ModbusDevice] ID " + str(self.__serial__) + " starting...")
         self.__monitorthread__ = threading.Thread(target=self.__run__, name="Monitor " + str(self.__serial__))
         self.__monitorthread__.start()
         self.__modbusThread__ = threading.Thread(target=self.__runmodbus__, name="Modbus " + str(self.__serial__))
@@ -94,20 +94,20 @@ class ModbusDevice:
         time.sleep(1)
         for connection in self.__connections__:
             connection.connect()
-        logging.debug("[Device] ID " + str(self.__serial__) + " started.")
+        logging.debug("[ModbusDevice] ID " + str(self.__serial__) + " started.")
     
     def stop(self):
         self.__running__ = False
-        logging.info("[Device] ID " + str(self.__serial__) + " stopping.")
+        logging.info("[ModbusDevice] ID " + str(self.__serial__) + " stopping.")
         if(self.__modbusThread__ != None and self.__modbusThread__.is_alive()):
             self.__modbusThread__.join(3)     # todo: konstante verwenden
         for connection in self.__connections__:
             try:
                 connection.loadlogdata()
                 connection.sendlogdata()
-                logging.info("[Device] ID " + str(self.__serial__) + " logdata sent.")
+                logging.info("[ModbusDevice] ID " + str(self.__serial__) + " logdata sent.")
             except:
-                logging.warning("[Device] ID " + str(self.__serial__) + " cannot send logdata while stopping.")
+                logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " cannot send logdata while stopping.")
             connection.disconnect()
     
     def getserial(self):
@@ -128,47 +128,47 @@ class ModbusDevice:
     def setmodbusfrequency(self, frequency):
         if frequency != None and frequency >= 0 and frequency < 90000:
             self.__modbusFrequency__ = frequency
-            logging.info("[Device] ID " + str(self.__serial__) + " modbus frequency set to " + str(self.__modbusFrequency__))
+            logging.info("[ModbusDevice] ID " + str(self.__serial__) + " modbus frequency set to " + str(self.__modbusFrequency__))
             return True
         else:
-            logging.info("[Device] ID " + str(self.__serial__) + " set modbus frequency failed. Out of range: " + str(frequency))
+            logging.info("[ModbusDevice] ID " + str(self.__serial__) + " set modbus frequency failed. Out of range: " + str(frequency))
             return False
 
     def setlogdatasendinterval(self, interval):
         if interval != None and interval >= 0 and interval < 90000:
             self.__logdatasendinterval__ = interval
-            logging.info("[Device] ID " + str(self.__serial__) + " logdata send interval set to " + str(self.__logdatasendinterval__))
+            logging.info("[ModbusDevice] ID " + str(self.__serial__) + " logdata send interval set to " + str(self.__logdatasendinterval__))
             return True
         else:
-            logging.info("[Device] ID " + str(self.__serial__) + " set logdata send interval failed. Out of range: " + str(interval))
+            logging.info("[ModbusDevice] ID " + str(self.__serial__) + " set logdata send interval failed. Out of range: " + str(interval))
             return False
 
     def setstartregister(self, startRegister):
         if startRegister != None and startRegister >= 0 and startRegister < 10000:
             self.__startRegister__ = startRegister
-            logging.info("[Device] ID " + str(self.__serial__) + " start-register set to " + str(self.__startRegister__))
+            logging.info("[ModbusDevice] ID " + str(self.__serial__) + " start-register set to " + str(self.__startRegister__))
             return True
         else:
-            logging.info("[Device] ID " + str(self.__serial__) + " set start-register failed. Out of range: " + str(startRegister))
+            logging.info("[ModbusDevice] ID " + str(self.__serial__) + " set start-register failed. Out of range: " + str(startRegister))
             return False
 
     def setregisterstoread(self, registersToRead):
         if registersToRead != None and registersToRead > 0 and registersToRead < 10000:
             self.__registersToRead__ = registersToRead
-            logging.info("[Device] ID " + str(self.__serial__) + " registersToRead set to " + str(self.__registersToRead__))
+            logging.info("[ModbusDevice] ID " + str(self.__serial__) + " registersToRead set to " + str(self.__registersToRead__))
             return True
         else:
-            logging.info("[Device] ID " + str(self.__serial__) + " set registersToRead failed. Out of range: " + str(registersToRead))
+            logging.info("[ModbusDevice] ID " + str(self.__serial__) + " set registersToRead failed. Out of range: " + str(registersToRead))
             return False
 
     def __run__(self):
         while self.__running__:
-            logging.debug("[Device] ID " + str(self.__serial__) + " monitor running...")
+            logging.debug("[ModbusDevice] ID " + str(self.__serial__) + " monitor running...")
             for connection in self.__connections__:
                 try:
                     connection.watchdog()
                 except:
-                    logging.error("[Device] ID " + str(self.__serial__) + " watchdog failed.")
+                    logging.error("[ModbusDevice] ID " + str(self.__serial__) + " watchdog failed.")
 
             if self.__logdatasendinterval__ > 0:
                 if self.__lastlogdataSendTime__ == None:
@@ -181,13 +181,13 @@ class ModbusDevice:
                                 connection.loadlogdata()
                                 connection.sendlogdata()
                                 self.__lastlogdataSendTime__ = datetime.now()
-                                logging.info("[Device] ID " + str(self.__serial__) + " active sent logdata to server: " + str(connection.getServer()))
+                                logging.info("[ModbusDevice] ID " + str(self.__serial__) + " active sent logdata to server: " + str(connection.getServer()))
                             except Exception as e:
-                                logging.warning("[Device] ID " + str(self.__serial__) + " active sending logdata to server " + str(connection.getServer()) + " failed. " + str(e))
+                                logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " active sending logdata to server " + str(connection.getServer()) + " failed. " + str(e))
             try:
                 self.__supervise__()
             except Exception as e:
-                logging.warning("[Device] ID " + str(self.__serial__) + " supervision failed failed. " + str(e))
+                logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " supervision failed failed. " + str(e))
 
             if self.__modBusExecuted__ != None:
                 difference = datetime.now() - self.__modBusExecuted__
@@ -220,7 +220,7 @@ class ModbusDevice:
         try:
             self.__setup__[key]
         except Exception as e:
-            logging.warning("[Device] ID " + str(self.__serial__) + " Setup-Element does not exist: " + str(e))
+            logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " Setup-Element does not exist: " + str(e))
             raise Exception("setup element does not exist.")
         try:
             self.__setup__[key] = value
@@ -229,13 +229,13 @@ class ModbusDevice:
                 self.writeregister(register, value)
                 registervalue = self.readregister(register)
                 if registervalue != value:
-                    logging.warning("[Device] ID " + str(self.__serial__) + " Register verification failed. " + str(registervalue[register]))
+                    logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " Register verification failed. " + str(registervalue[register]))
                     raise Exception("register verification failed.")
             else:
-                logging.debug("[Device] ID " + str(self.__serial__) + " no register mapping for key " + str(key))
+                logging.debug("[ModbusDevice] ID " + str(self.__serial__) + " no register mapping for key " + str(key))
 
         except Exception as e:
-            logging.info("[Device] ID " + str(self.__serial__) + " Setup change not successfull. " + str(e))
+            logging.info("[ModbusDevice] ID " + str(self.__serial__) + " Setup change not successfull. " + str(e))
             raise e
 
     def __supervise__(self):
@@ -243,20 +243,20 @@ class ModbusDevice:
         for connection in self.__connections__:
             try:
                 if not connection.isconnected():
-                    logging.info("[Device] " + self.getidentifier() + " not connected to " + str(connection.getServer()))
+                    logging.info("[ModbusDevice] " + self.getidentifier() + " not connected to " + str(connection.getServer()))
                     errors += 1
             except Exception as e:
-                logging.warning("[Device] " + self.getidentifier() + " cannot check connection to " + str(connection.getServer()) + ". " + str(e))
+                logging.warning("[ModbusDevice] " + self.getidentifier() + " cannot check connection to " + str(connection.getServer()) + ". " + str(e))
         if errors == 0:
-            logging.debug("[Device] " + self.getidentifier() + ": DCS-Connections ok.")
+            logging.debug("[ModbusDevice] " + self.getidentifier() + ": DCS-Connections ok.")
 
     def __sethealthstate__(self, state):
         if state != None and state <= 3 and state >= 0:
             if self.__healthState__ != state:
                 self.__healthState__ = state
-                logging.info("[Device] " + self.getidentifier() + ". HealthState set to " + str(state))
+                logging.info("[ModbusDevice] " + self.getidentifier() + ". HealthState set to " + str(state))
         else:
-            logging.error("[Device] " + self.getidentifier() + ". Cannot set healthState. Invalid state: " + str(state))
+            logging.error("[ModbusDevice] " + self.getidentifier() + ". Cannot set healthState. Invalid state: " + str(state))
             raise Exception("invalid state " + str(state))
 
     def getHealthState(self):
@@ -268,26 +268,26 @@ class ModbusDevice:
                 self.__modBusExecuted__ = datetime.now()
                 self.__excecutemodbus__()
             except Exception as e:
-                logging.error("[Device] " + self.getidentifier() + ". Modbus Thread Error: " + str(e))
+                logging.error("[ModbusDevice] " + self.getidentifier() + ". Modbus Thread Error: " + str(e))
 
     def __excecutemodbus__(self):
         if self.__modbusFrequency__ > 0:
-            logging.debug("[Device] ID " + str(self.__serial__) + " Modbus running...")
+            logging.debug("[ModbusDevice] ID " + str(self.__serial__) + " Modbus running...")
             self.__readallregisters__()
             if self.__registers__ != None:
                 if len(self.__registers__) > 0:
                     try:
                         self.__syncsettings__()
                     except Exception as e:
-                        logging.warning("[Device] " + self.getidentifier() + ". Settingssync not successfull. " + str(e))
+                        logging.warning("[ModbusDevice] " + self.getidentifier() + ". Settingssync not successfull. " + str(e))
                     try:
                         self.__processregisters__()
                     except Exception as e:
-                        logging.warning("[Device] " + self.getidentifier() + ". processing registers not successfull. " + str(e))
+                        logging.warning("[ModbusDevice] " + self.getidentifier() + ". processing registers not successfull. " + str(e))
                 else:
-                    logging.warning("[Device] " + self.getidentifier() + ". No bus communication to device.")
+                    logging.debug("[ModbusDevice] " + self.getidentifier() + ". No bus communication to device.")
             else:
-                logging.debug("[Device] " + self.getidentifier() + ". No registers to process.")
+                logging.debug("[ModbusDevice] " + self.getidentifier() + ". No registers to process.")
             time.sleep(self.__modbusFrequency__)
 
     def __syncsettings__(self):
@@ -297,22 +297,22 @@ class ModbusDevice:
                 if self.__settingsMap__[name]["register"] in self.__registers__:
                     if name in self.__setup__:
                         if self.__registers__[self.__settingsMap__[name]["register"]] != self.__setup__[name]:
-                            logging.info("[Device] ID " + str(self.__serial__) + " setting missmatch " + str(name) + " - Device: " + str(self.__registers__[self.__settingsMap__[name]["register"]]) + "; Setup: " + str(self.__setup__[name]) + ".")
+                            logging.info("[ModbusDevice] ID " + str(self.__serial__) + " setting missmatch " + str(name) + " - Device: " + str(self.__registers__[self.__settingsMap__[name]["register"]]) + "; Setup: " + str(self.__setup__[name]) + ".")
                             if self.__settingsMap__[name]["forced"]:
                                 try:
                                     self.writeregister(self.__settingsMap__[name]["register"], self.__setup__[name])
                                 except Exception as e:
-                                    logging.warning("[Device] ID " + str(self.__serial__) + " cannot write register while settings sync. Set " + str(name) + " to "+str(self.__setup__[name])+". " + str(e))
-                                logging.info("[Device] ID " + str(self.__serial__) + " forcing " + str(name) + " to "+str(self.__setup__[name])+".")
+                                    logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " cannot write register while settings sync. Set " + str(name) + " to "+str(self.__setup__[name])+". " + str(e))
+                                logging.info("[ModbusDevice] ID " + str(self.__serial__) + " forcing " + str(name) + " to "+str(self.__setup__[name])+".")
                             else:
                                 self.__setup__[name] = self.__registers__[self.__settingsMap__[name]["register"]]
                                 self.sendsetup()
-                                logging.debug("[Device] ID " + str(self.__serial__) + " changed setup. " + str(name) + "=" + str(self.__setup__[name]) + ".")
+                                logging.debug("[ModbusDevice] ID " + str(self.__serial__) + " changed setup. " + str(name) + "=" + str(self.__setup__[name]) + ".")
                     else:
-                        logging.warning("[Device] ID " + str(self.__serial__) + " setting element " + str(name) + " not found in setup.")
+                        logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " setting element " + str(name) + " not found in setup.")
                         errors += 1
                 else:
-                    logging.warning("[Device] ID " + str(self.__serial__) + " register for setting " + str(name) + " not found.")
+                    logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " register for setting " + str(name) + " not found.")
                     errors += 1
         if errors == 0:
             return True
@@ -326,7 +326,7 @@ class ModbusDevice:
                 try:
                     connection.sendsetup()
                 except Exception:
-                    logging.error("[Device] ID " + str(self.__serial__) + " cannot send setup change to server.")
+                    logging.error("[ModbusDevice] ID " + str(self.__serial__) + " cannot send setup change to server.")
                     success = False
         return success
 
@@ -348,7 +348,7 @@ class ModbusDevice:
 
     def __readallregisters__(self):
         if self.__startRegister__ != None and self.__registersToRead__ != None:
-            logging.debug("[Device] ID " + str(self.__serial__) + " reading " + str(self.__registersToRead__) + " registers starting with " + str(self.__startRegister__))
+            logging.debug("[ModbusDevice] ID " + str(self.__serial__) + " reading " + str(self.__registersToRead__) + " registers starting with " + str(self.__startRegister__))
             registers = self.__readregisters__(self.__startRegister__, self.__registersToRead__)
             if registers != None:
                 self.__registers__ = registers
@@ -358,12 +358,12 @@ class ModbusDevice:
             if registers != None and len(registers) > 0:
                 self.__registerLastSuccessfullReadTimeStamp__ = time.time()
         else:
-            logging.warning("[Device] ID " + str(self.__serial__) + " no registers to read")
+            logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " no registers to read")
 
     def __readregisters__(self, startregisteraddress, registerstoread):
         with self.__lock__:
             registers = dict()
-            logging.info("[Device] ID " + str(self.__serial__) + " creating dummy data for " + str(self.__registersToRead__) + " registers")
+            logging.info("[ModbusDevice] ID " + str(self.__serial__) + " creating dummy data for " + str(self.__registersToRead__) + " registers")
             for i in range(registerstoread):
                 registers[startregisteraddress + i] = i*1000
                 if(i == 3):
@@ -398,7 +398,7 @@ class ModbusDevice:
 
     def __writeregister__(self, registerId, valueToWrite):
         with self.__lock__:
-            logging.debug("[Device] ID " + str(self.__serial__) + " writing register " + str(registerId) + " value: " + str(valueToWrite))
+            logging.debug("[ModbusDevice] ID " + str(self.__serial__) + " writing register " + str(registerId) + " value: " + str(valueToWrite))
             self.__registers__[registerId] = valueToWrite
 
     def getregistervalue(self, registerId):
@@ -412,7 +412,7 @@ class ModbusDevice:
                 else:
                     value = None
             except Exception:
-                logging.warning("[Device] ID " + str(self.__serial__) + " register not found. Register Id: " + str(registerId))
+                logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " register not found. Register Id: " + str(registerId))
                 value = None
         return value
 
@@ -426,12 +426,12 @@ class ModbusDevice:
                     value = register["value"]
                     self.__data__[dataset] = value
                     self.__addtologdata__(dataset, register)
-                    logging.debug("[Device] ID " + str(self.__serial__) + ", dataset=" + str(dataset) + ", value=" + str(value) + " processed")
+                    logging.debug("[ModbusDevice] ID " + str(self.__serial__) + ", dataset=" + str(dataset) + ", value=" + str(value) + " processed")
                 else:
-                    logging.debug("[Device] ID " + str(self.__serial__) + " no value for dataset " + str(dataset))
+                    logging.debug("[ModbusDevice] ID " + str(self.__serial__) + " no value for dataset " + str(dataset))
                     self.__data__[dataset] = None
         else:
-            logging.warning("[Device] ID " + str(self.__serial__) + " no datasets defined")
+            logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " no datasets defined")
         self.__logdataTimeStamp__ = self.__registerTimeStamp__
 
     def __addtologdata__(self, datasetname, register):
@@ -478,7 +478,7 @@ class ModbusDevice:
         try:
             return self.__data__[datasetname]
         except Exception:
-            logging.warning("[Device] ID " + str(self.__serial__) + " dataset not found " + str(datasetname))
+            logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " dataset not found " + str(datasetname))
             return None 
 
     def getlogvalue(self, datasetname):
@@ -488,7 +488,7 @@ class ModbusDevice:
         try:
             return self.__logdata__[datasetname]
         except Exception:
-            logging.warning("[Device] ID " + str(self.__serial__) + " logvalue not found " + str(datasetname))
+            logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " logvalue not found " + str(datasetname))
             return None
 
     def getintlogvalue(self, datasetname):
@@ -507,16 +507,16 @@ class ModbusDevice:
     def showinfo(self):
         if self.__datasets__ != None:
             for dataset in self.__datasets__:
-                logging.info("[Device] ID " + str(self.__serial__) + " " + dataset + ": Live: " + str(self.getdataset(dataset)) + ", Log: " + str(self.getlogvalue(dataset)) + ", HealthState: " + str(self.getHealthState()))
+                logging.info("[ModbusDevice] ID " + str(self.__serial__) + " " + dataset + ": Live: " + str(self.getdataset(dataset)) + ", Log: " + str(self.getlogvalue(dataset)) + ", HealthState: " + str(self.getHealthState()))
         else:
-            print("[Device] ID " + str(self.__serial__) + " no datasets defined")
-            logging.info("[Device] ID " + str(self.__serial__) + " no datasets defined")
+            print("[ModbusDevice] ID " + str(self.__serial__) + " no datasets defined")
+            logging.info("[ModbusDevice] ID " + str(self.__serial__) + " no datasets defined")
 
     def getcommunicationerrorscounter(self):
         return 0
 
     def showcommunicationerrors(self):
-        logging.info("[Device] " + str(self.__serial__) + " - Communication Errors: " +  str(self.getcommunicationerrorscounter()))
+        logging.info("[ModbusDevice] " + str(self.__serial__) + " - Communication Errors: " +  str(self.getcommunicationerrorscounter()))
 
     def getcommunicationerrorsrate(self):
         return 0
@@ -525,7 +525,7 @@ class ModbusDevice:
         rate = self.getcommunicationerrorsrate()
         if rate != None:
             rate = round(rate*100)
-        logging.info("[Device] " + str(self.getidentifier()) + " - Communication error-rate: " +  str(rate) + "%, Errors: " +  str(self.getcommunicationerrorscounter()))
+        logging.info("[ModbusDevice] " + str(self.getidentifier()) + " - Communication error-rate: " +  str(rate) + "%, Errors: " +  str(self.getcommunicationerrorscounter()))
 
     def __createDataset__(self, registerId, type):
         dataset = [registerId, type]
@@ -1108,7 +1108,7 @@ if __name__ == "__main__":
     device.start()
     try:
         while True:
-            print(color('[Device] DCS communication active. Press CTRL+C to stop', fore='blue', style='bright'))
+            print(color('[ModbusDevice] DCS communication active. Press CTRL+C to stop', fore='blue', style='bright'))
             device.showinfo()
             device.showcommunicationerrors()
             device.showcommunicationerrorsrate()
